# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_ocm_global_optspecs
	string join \n c/config= p/profile= f/force no-post-action-scripts v/verbose q/quiet h/help V/version
end

function __fish_ocm_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_ocm_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_ocm_using_subcommand
	set -l cmd (__fish_ocm_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c ocm -n "__fish_ocm_needs_command" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_needs_command" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_needs_command" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_needs_command" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_needs_command" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_needs_command" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_needs_command" -s V -l version -d 'Print version'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "complete" -d 'Generate shell completion to stdout'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "init-config" -d 'Initialise a config file'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "init" -d 'Initialise a config file'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "list-profiles" -d 'List all known profiles'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "profiles" -d 'List all known profiles'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "list" -d 'List all certificates, with optional filtering'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "ls" -d 'List all certificates, with optional filtering'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "new-user" -d 'Generate a certificate for a new user'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "new" -d 'Generate a certificate for a new user'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "rm-user" -d 'Revoke the certificate for an existing user'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "rm" -d 'Revoke the certificate for an existing user'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "package-for" -d 'Create redistributable packages for the specified users'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "pkg" -d 'Create redistributable packages for the specified users'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "package" -d 'Create redistributable packages for the specified users'
complete -c ocm -n "__fish_ocm_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand complete" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand complete" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand init-config" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand init" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand init" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand init" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand init" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand init" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand init" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand init" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand list-profiles" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand profiles" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand list" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand list" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand list" -s e -l expired -d 'Only show expired certificates'
complete -c ocm -n "__fish_ocm_using_subcommand list" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand list" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand list" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand list" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s e -l expired -d 'Only show expired certificates'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand ls" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s d -l days -d 'The number of days this certificate stays valid' -r
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand new-user" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand new" -s d -l days -d 'The number of days this certificate stays valid' -r
complete -c ocm -n "__fish_ocm_using_subcommand new" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand new" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand new" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand new" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand new" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand new" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand new" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -l no-update-crl -d 'Do not update crl.pem file'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand rm-user" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand rm" -l no-update-crl -d 'Do not update crl.pem file'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand rm" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s o -l output-dir -d 'Output to a directory other than the current working directory' -r -f -a "(__fish_complete_directories)"
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -l add-prefix -l pre -d 'Add the profile name as a prefix to the package name'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -l keep-temp -d 'Keep temporary intermediate artifacts instead of deleting them. Helpful for debugging'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand package-for" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s o -l output-dir -d 'Output to a directory other than the current working directory' -r -f -a "(__fish_complete_directories)"
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -l add-prefix -l pre -d 'Add the profile name as a prefix to the package name'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -l keep-temp -d 'Keep temporary intermediate artifacts instead of deleting them. Helpful for debugging'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand pkg" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand package" -s o -l output-dir -d 'Output to a directory other than the current working directory' -r -f -a "(__fish_complete_directories)"
complete -c ocm -n "__fish_ocm_using_subcommand package" -s c -l config -d 'Path to the configuration file' -r -F
complete -c ocm -n "__fish_ocm_using_subcommand package" -s p -l profile -d 'Manually select a profile to operate on' -r
complete -c ocm -n "__fish_ocm_using_subcommand package" -l add-prefix -l pre -d 'Add the profile name as a prefix to the package name'
complete -c ocm -n "__fish_ocm_using_subcommand package" -l keep-temp -d 'Keep temporary intermediate artifacts instead of deleting them. Helpful for debugging'
complete -c ocm -n "__fish_ocm_using_subcommand package" -s f -l force -d 'Proceed with potentially destructive actions automatically without confirmation'
complete -c ocm -n "__fish_ocm_using_subcommand package" -l no-post-action-scripts -l no-post-scripts -d 'Do not run post-action scripts'
complete -c ocm -n "__fish_ocm_using_subcommand package" -s v -l verbose -d 'Increase logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand package" -s q -l quiet -d 'Decrease logging verbosity'
complete -c ocm -n "__fish_ocm_using_subcommand package" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "complete" -d 'Generate shell completion to stdout'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "init-config" -d 'Initialise a config file'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "list-profiles" -d 'List all known profiles'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "list" -d 'List all certificates, with optional filtering'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "new-user" -d 'Generate a certificate for a new user'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "rm-user" -d 'Revoke the certificate for an existing user'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "package-for" -d 'Create redistributable packages for the specified users'
complete -c ocm -n "__fish_ocm_using_subcommand help; and not __fish_seen_subcommand_from complete init-config list-profiles list new-user rm-user package-for help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
